@@ -2087,6 +2087,11 @@ vpg_update (sqlite3_vtab * pVTab, int argc, sqlite3_value ** argv,
     VirtualPgPtr p_vt = (VirtualPgPtr) pVTab;
     if (p_vt->readOnly)
 	return SQLITE_READONLY;
+    if (p_vt->pg_conn == NULL)
+      {
+	  /* last attempt to establish a DB connection */
+	  p_vt->pg_conn = vpgPQconnectdb (p_vt->ConnInfo);
+      }
     if (argc == 1)
       {
 	  /* performing a DELETE */
